use `ombutel`;

insert into `ombu_modules` (`name`, `has_dialplan`, `admin`, `portal`) values
  ('fax_devices', 'no', 'yes', 'no'),
  ('fax_general_settings', 'no', 'yes', 'no'),
  ('fax_sending', 'no', 'yes', 'yes'),
  ('fax_viewer', 'no', 'yes', 'yes');

select `role_id` into @main_role from `ombu_roles` where `role` = 'super_administrator' limit 1;

insert into `ombu_role_privileges` (`role_id`,`module_id`, `allow_view`, `allow_add`, `allow_edit`, `allow_delete`)
  select
    @main_role,
    `module_id`,
    'yes',
    'yes',
    'yes',
    'yes'
  from `ombu_modules`
  where `name` in ('fax_devices', 'fax_general_settings', 'fax_sending', 'fax_viewer');

insert into `ombu_menu` (`label`, `parent_id`, `module_id`, `sort`, `icon`)
  select
    'menu.virtual_faxes',
    `menu_id`,
    null,
    30,
    'fa fa-fw fa-fax'
  from `ombu_menu`
  where `label` = 'menu.pbx' and `parent_id` is null;


set @parent_menu_id = last_insert_id();
set @n = 0;

insert into `ombu_menu` (`label`, `parent_id`, `module_id`, `sort`)
  select
    CONCAT('menu', '.', `name`),
    @parent_menu_id,
    `module_id`,
    @n := @n + 1
  from `ombu_modules`
  where `name` in ('fax_general_settings', 'fax_devices', 'fax_viewer', 'fax_sending');

create table `ombu_fax_devices` (
  `id` int unsigned not null auto_increment,
  `description` varchar(255) not null,
  `cos_id` int unsigned not null,
  `secret` varchar(255) not null,
  `associated_email` varchar(255) null default null,
  `cid_name` varchar(255) null default null,
  `cid_number` varchar(255) null default null,
  `country_code` int unsigned null default null,
  `area_code` int unsigned null default null,
  primary key (`id`),
  foreign key (`cos_id`) references `ombu_classes_of_service` (`class_of_service_id`) on delete restrict
);

select `module_id` into @fax_general_settings_module from `ombu_modules` where `name` = 'fax_general_settings';

insert ignore into `ombu_settings` (`module_id`, `name`, `value`) values
  (@fax_general_settings_module, 'allowed_ip_addresses', '127.0.0.1,localhost'),
  (@fax_general_settings_module, 'notifications_email', 'faxmaster@vitalpbx.org'),
  (@fax_general_settings_module, 'country_code', 1),
  (@fax_general_settings_module, 'area_code', 754),
  (@fax_general_settings_module, 'long_distance_prefix', 1),
  (@fax_general_settings_module, 'international_prefix', '011'),
  (@fax_general_settings_module, 'devices_port', 3570)
on duplicate key update `value` = if(`value` = "", values(`value`), `value`);

create table `ombu_faxes_log` (
  `id` int unsigned not null auto_increment,
  `date` datetime not null default '0000-00-00 00:00:00',
  `type` enum('in', 'out') not null default 'out',
  `fax_device` varchar(255) not null,
  `sender` varchar(255) not null,
  `sender_number` varchar(255) null default null,
  `recipient` varchar(255) not null,
  `pdf_file` varchar(255) null default null,
  `status` varchar(255) not null,
  primary key (`id`)
);

select `module_id` into @fax_devices_module from `ombu_modules` where `name` = 'fax_devices';

insert into `ombutel`.`ombu_destinations_category` (`module_id`) values
  (@fax_devices_module);

select `role_id` into @portal_role from `ombu_roles` where `role` = 'Portal' and `default` = 'yes' limit 1;

insert into `ombu_role_privileges` (`role_id`,`module_id`, `allow_view`, `allow_add`, `allow_edit`, `allow_delete`)
  select
    @portal_role,
    `module_id`,
    'yes',
    'yes',
    'yes',
    'yes'
  from `ombu_modules`
  where `name` in ('fax_sending', 'fax_viewer');

update `ombu_users` set `fax_device_id` = null;

alter table `ombu_users`
  add foreign key (`fax_device_id`) references `ombu_fax_devices` (`id`) on delete set null;